@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * atom.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -18,9 +18,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  * Boston, MA  02111-1307, USA.
  */
 
@@ -146,7 +147,7 @@ void Atom::Transform2D(Matrix2D& m, double x, double y)
 
 xmlNodePtr Atom::Save(xmlDocPtr xml)
 {
-	xmlNodePtr parent, child;
+	xmlNodePtr parent;
 	gchar buf[16];
 	parent = xmlNewDocNode(xml, NULL, (xmlChar*)"atom", NULL);
 	if (!parent) return NULL;
@@ -167,8 +168,7 @@ xmlNodePtr Atom::Save(xmlDocPtr xml)
 
 bool Atom::Load (xmlNodePtr node)
 {
-	char* tmp, *endptr;
-	xmlNodePtr child;
+	char* tmp;
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "id");
 	if (tmp) {
 		SetId (tmp);
